=========================================
Climate Impact Lab development toolkit
=========================================


.. image:: https://img.shields.io/pypi/v/impactlab-tools.svg
        :target: https://pypi.python.org/pypi/impactlab-tools

.. image:: https://travis-ci.org/ClimateImpactLab/impactlab-tools.svg?branch=master
        :target: https://travis-ci.org/ClimateImpactLab/impactlab-tools?branch=master

.. image:: https://coveralls.io/repos/github/ClimateImpactLab/impactlab-tools/badge.svg?branch=master
        :target: https://coveralls.io/github/ClimateImpactLab/impactlab-tools?branch=master

.. image:: https://readthedocs.com/projects/impactlab-tools/badge/?version=latest
        :target: https://impactlab-tools.readthedocs.com/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/climateimpactlab/impactlab-tools/shield.svg
     :target: https://pyup.io/repos/github/climateimpactlab/impactlab-tools/
     :alt: Updates


Python tools for Climate Impact Lab developers


* Documentation: https://impactlab-tools.readthedocs.com.


Features
--------




Usage
-----


Installation
------------

``pip install impactlab-tools``




Requirements
------------


Todo
----

See `issues <https://bitbucket.org/ClimateImpactLab/impactlab-tools/issues>`_ to see and add to our todos.


Credits
---------

This package was created by `Justin Simcock <https://github.com/jgerardsimcock>`_ and `Michael Delgado <https://github.com/delgadom>`_ of the `Climate Impact Lab <http://impactlab.org>`_. Check us out on `github <https://github.com/ClimateImpactLab>`_.
